@@ -81,19 +81,18 @@ class table_objects:
             content = self.obj.crypto.encrypt_to_str(json.dumps(datas))
             )
 
+        new_column = SqleeColumn(
+                            path = URL(self.obj.name) / column,
+                            repo = self.obj.repo,
+                            index = self.obj.index,
+                            index_data = column,
+                            table = self.obj,
+                            namespace = self.obj.namespace,
+                            )
         self.obj.columns = list(self.obj.columns)
-        self.obj.columns.append(
-                SqleeColumn(
-                    path = URL(self.obj.name) / column,
-                    repo = self.obj.repo,
-                    index = self.obj.index,
-                    index_data = column,
-                    table = self.obj,
-                    namespace = self.obj.namespace,
-                    )
-                )
+        self.obj.columns.append(new_column)
         self.obj.columns = tuple(self.obj.columns)
-        return self.obj.columns
+        return new_column
 
     def delete(self, *args, **kwargs):
         """ Usage: delete(**namespace) """
@@ -236,7 +235,7 @@ class SqleeColumn:
     def delete(self):
         """ Usage: delete() """
         self.repo.delete_file(path = self.path)
-        del self
+        self.table.columns.remove(self)
         return True
 
 class SqleeTable:
