@@ -10,9 +10,11 @@ import json
 import base64
 
 if __name__ == "__main__":
-    from utils.exceptions import RepositoryNotFoundError, RepositoryConnectionRefusedError, InternetError
+    from exceptions import (RepositoryNotFoundError, RepositoryConnectionRefusedError,
+                            InternetError, ColumnNotFoundError, RepositoryNotFound)
 else:
-    from .exceptions import RepositoryNotFoundError, RepositoryConnectionRefusedError, InternetError, ColumnNotFoundError
+    from .exceptions import (RepositoryNotFoundError, RepositoryConnectionRefusedError,
+                                  InternetError, ColumnNotFoundError, RepositoryNotFound)
 
 class GiteeRepo:
     token = None
@@ -25,19 +27,9 @@ class GiteeRepo:
         self.url = "https://gitee.com/" + user + "/" + repo + "/"
 
         try:
-            query = requests.get(
-                url = "https://gitee.com/api/v5/user/repos",
-                data = {"access_token": token}
-                )
-            all_repos = query.json()
-            exists = False
-            for repos in all_repos:
-                if repo == repos["name"] and user == repos["owner"]["login"]:
-                    exists = True
+            exists = self.has_repo(name=repo, user=user, token=token)
             if not exists:
                 raise RepositoryNotFoundError(self.repo)
-            if query.status_code // 100 != 2:
-                raise RepositoryConnectionRefusedError(self.repo, status_code=status_code)
         except requests.RequestException:
             raise InternetError()
 
@@ -45,6 +37,21 @@ class GiteeRepo:
         self.types["int"] = int
         self.types["str"] = str
 
+    @staticmethod
+    def has_repo(name=None, user=None, token=None):
+        query = requests.get(
+                url = "https://gitee.com/api/v5/user/repos",
+                data = {"access_token": token}
+                )
+        if query.status_code // 100 != 2:
+            raise RepositoryConnectionRefusedError(self.repo, status_code=status_code)
+        all_repos = query.json()
+        exists = False
+        for repos in all_repos:
+            if name == repos["name"] and user == repos["owner"]["login"]:
+                exists = True
+        return exists
+
     def get_file(self, path=None):
         query = requests.get(
             url = f"https://gitee.com/api/v5/repos/{self.user}/{self.repo}/contents/{path}?access_token={self.token}"
@@ -205,6 +212,11 @@ class GiteeRepo:
 def make_repo(token=None, user=None, name=None, private=True, auto_init=True):
     if not token or not user or not name:
         raise ValueError("参数不全.")
+    if GiteeRepo.has_repo(name=name, user=user, token=token):
+        print("仓库 %s 已存在." % name)
+        return
+    else:
+        print(RepositoryNotFound(name))
     return requests.post(
         url = "https://gitee.com/api/v5/user/repos",
         data = {
@@ -213,15 +225,4 @@ def make_repo(token=None, user=None, name=None, private=True, auto_init=True):
             'auto_init': auto_init,
             'private': private,
         }
-    )
-if __name__ == "__main__":
-    pass
-    #db = GiteeRepo(token="1895956f770eb0e4d08013ee4b753203", user="fu050409", repo="TEST_API")
-    #db.drop_folder(path="Table")
-    #print(gitee.get_file("TEST"))
-    #print(gitee.list_file(""))
-    #print(gitee.list_folder("Table", int=True))
-    #print(gitee.list_folder("Table", int=False, detail=True))
-    #print(gitee.upload_file(path="TEST_UPLOAD", content="测试上传文件"))
-    #print(gitee.delete_file(path="TEST_UPLOAD"))
-    #print(gitee.update_file(path="TEST_COMMITTER", content="测试更新文件"))
+    )
\ No newline at end of file
